Class: HighFive::Thor::Tasks::Distribution

Inherits:
HighFive::Thor::Task show all
Includes:
AndroidHelper, IosHelper, Thor::Actions
Defined in:
lib/high_five/thor/tasks/distribution.rb

Instance Method Summary collapse

Methods included from AndroidHelper

#android_manifest_path, #parse_resolution, project_name_from_build_xml, #res_map, #valid_directories

Methods included from IosHelper

#info_plist_path, #xcodeproj_path

Methods inherited from HighFive::Thor::Task

banner, #initialize

Constructor Details

This class inherits a constructor from HighFive::Thor::Task

Instance Method Details

#dist(platform) ⇒ Object



18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/high_five/thor/tasks/distribution.rb', line 18

def dist(platform)
  @output_file_name       = options[:output_file_name]
  @sign_identity          = options[:sign_identity]
  @provisioning_profile   = options[:provisioning_profile]
  @platform               = platform
  @config                 = base_config.build_platform_config(@platform).build_platform_config(@environment)
  @config_root            = File.join("config", "high_five")

  raise "Please set config.destination" if @config.destination.nil?
  self.destination_root = @config.destination

  if @platform == "android" || @platform == "amazon"
    manifest_path = android_manifest_path
    android_path = File.dirname(manifest_path)

    dist_android(android_path)
  elsif @platform == "ios"
    raise "Please pass in the code sign identity to build an ios app. -s [sign_identity]" if @sign_identity.nil?
    raise "Please pass in the path to the provisioning profile to build an ios app. -p [provisioning_profile]" if @provisioning_profile.nil?

    ios_path = File.dirname(xcodeproj_path())

    if !ios_path
      raise "Couldn't find the path of the xcodeproj."
    end

    ios_project_name = File.basename(Dir[ios_path + "/*.xcodeproj"].first, '.xcodeproj')
    ios_target = options[:target] || ios_project_name
    keychain = ios_project_name.gsub(/\s/, '').gsub(/([A-Z]+)([A-Z][a-z])/,'\1_\2').gsub(/([a-z\d])([A-Z])/,'\1_\2').tr("-", "_").downcase + '-ios.keychain'

    @output_file_name ||= ios_target

    uuid = HighFive::IosHelper.uuid_from_mobileprovision(@provisioning_profile)
    ENV['uuid'] = uuid
    FileUtils.cp(@provisioning_profile, "#{ENV['HOME']}/Library/MobileDevice/Provisioning Profiles/#{uuid}.mobileprovision")
    system(%Q(cd "#{ios_path}";
      /usr/bin/xcodebuild -target "#{ios_target}" -configuration Release build "CONFIGURATION_BUILD_DIR=#{ios_path}/build" "CODE_SIGN_IDENTITY=#{@sign_identity}" PROVISIONING_PROFILE=$uuid))
    system(%Q(/usr/bin/xcrun -sdk iphoneos PackageApplication -v "#{ios_path}/build/#{ios_target}.app" -o "#{ios_path}/build/#{@output_file_name}.ipa" --embed "#{@provisioning_profile}" --sign "#{@sign_identity}"))
  end
end

#dist_android(android_path) ⇒ Object



61
62
63
64
65
66
67
68
69
70
# File 'lib/high_five/thor/tasks/distribution.rb', line 61

def dist_android(android_path)
  @output_file_name       = options[:output_file_name]
  system("android update project --path #{android_path} --subprojects")
  system("ant -file '#{android_path}/build.xml' release")

  android_name = HighFive::AndroidHelper.project_name_from_build_xml("#{android_path}/build.xml")
  if @output_file_name
    FileUtils.cp("#{android_path}/bin/#{android_name}-release.apk", "#{android_path}/bin/#{@output_file_name}.apk")
  end
end